var html = "<section class=\"mt-10\"><h1 id=\"serverseitiges-rendering\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#serverseitiges-rendering\">#</a> Serverseitiges Rendering</h1><p>Solid handhabt serverseitiges Rendering, indem es JSX-Templates zu extrem effizientem String-anfügendem Code rendert. Das kann mit dem Babel-Plugin erreicht werden, oder indem man <code>generate: ssr</code> durchreicht. Sowohl für Client als auch Server muss <code>hydratable: true</code> konfiguriert sein, damit mit Hydration kompatibler Code erzeugt wird.</p><p>Die <code>solid-js</code> und <code>solid-js/web</code> Laufzeit-Umgebungen werden mit nicht-reaktiven Entsprechungen getauscht, wenn sie in einer node-Umgebung laufen. Für andere Umgebungen muss man den Server-Code mit conditionalen Exporten auf <code>node</code> gesetzt bündeln. Die meisten Code-Bundler haben einen Weg, dies zu tun. Generell empfehlen wir, außerdem die <code>solid</code> Export-Konditionen zu benutzen und dass Libraries ihren Code unter dem <code>solid</code> export verteilen.</p><p>Für SSR zu bauen, benötigt definitiv mehr Konfiguration, da wir 2 separate Bündel bauen. Das Client-Script sollte <code>hydrate</code> benutzen:</p><pre class=\"shiki\" style=\"background-color:#fffffe\"><code><span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { hydrate } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-js/web&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6f42c1\">hydrate</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> &lt;</span><span style=\"color:#22863a\">App</span><span style=\"color:#24292e\"> /&gt;, document);</span></span>\n<span class=\"line\"></span></code></pre><p><em>Hinweis: Es ist möglich, vom document-Root aus zu rendern und zu hydrieren. Das erlaubt es uns, den gesamten View in JSX zu beschreiben.</em></p><p>Das Server-Script kann eine der vier Render-Methoden verwenden, die von Solid zur Verfügung gestellt werden. Jede erzeugt die Ausgabe und das Script-Tag, das in den Kopf des Dokuments eingefügt wird.</p><pre class=\"shiki\" style=\"background-color:#fffffe\"><code><span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  renderToString,</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  renderToStringAsync,</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  renderToNodeStream,</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  renderToWebStream,</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">} </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-js/web&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6a737d\">// Synchrones string rendering</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">html</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">renderToString</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> &lt;</span><span style=\"color:#22863a\">App</span><span style=\"color:#24292e\"> /&gt;);</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6a737d\">// Asynchrones string rendering</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">html</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">await</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">renderToStringAsync</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> &lt;</span><span style=\"color:#22863a\">App</span><span style=\"color:#24292e\"> /&gt;);</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6a737d\">// Node Stream API</span></span>\n<span class=\"line\"><span style=\"color:#6f42c1\">pipeToNodeWritable</span><span style=\"color:#24292e\">(App, res);</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6a737d\">// Web Stream API (etwa wie Cloudflare Workers)</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> { </span><span style=\"color:#005cc5\">readable</span><span style=\"color:#24292e\">, </span><span style=\"color:#005cc5\">writable</span><span style=\"color:#24292e\"> } </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">new</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">TransformStream</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#6f42c1\">pipeToWritable</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> &lt;</span><span style=\"color:#22863a\">App</span><span style=\"color:#24292e\"> /&gt;, writable);</span></span>\n<span class=\"line\"></span></code></pre><p>Bequemerweise exportiert <code>solid-js/web</code> ein <code>isServer</code>-Flag. Das ist nützlich, da viele JS-Bündler in der Lage sind, unbenutzten Code innerhalb von Abfragen dieses Flags mit Tree Shaking zu entfernen und imports, die nur von diesem Code genutzt werden, aus dem Client-Code herauszulassen.</p><pre class=\"shiki\" style=\"background-color:#fffffe\"><code><span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { isServer } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-js/web&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#d73a49\">if</span><span style=\"color:#24292e\"> (isServer) {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6a737d\">// das hier wird nur auf dem Server ausgeführt</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">} </span><span style=\"color:#d73a49\">else</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6a737d\">// das hier wird nur im Browser ausgeführt</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">}</span></span>\n<span class=\"line\"></span></code></pre><h2 id=\"hydrations-script\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#hydrations-script\">#</a> Hydrations-Script</h2><p>Um progressiv zu Hydrieren, noch before Solids Laufzeitumgebung geladen ist, muss ein spezielles Script in die Seite eingefügt werden. Es kann entweder generiert und per <code>generateHydrationScript</code> eingefügt werden oder als Teil des JSX, indem man das <code>&lt;HydrationScript /&gt;</code>-Tag benutzt.</p><pre class=\"shiki\" style=\"background-color:#fffffe\"><code><span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { generateHydrationScript } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-js/web&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">app</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">renderToString</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> &lt;</span><span style=\"color:#e36209\">App</span><span style=\"color:#24292e\"> /&gt;);</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">html</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">`</span></span>\n<span class=\"line\"><span style=\"color:#032f62\">  &lt;html lang=&quot;en&quot;&gt;</span></span>\n<span class=\"line\"><span style=\"color:#032f62\">    &lt;head&gt;</span></span>\n<span class=\"line\"><span style=\"color:#032f62\">      &lt;title&gt;🔥 Solid SSR 🔥&lt;/title&gt;</span></span>\n<span class=\"line\"><span style=\"color:#032f62\">      &lt;meta charset=&quot;UTF-8&quot; /&gt;</span></span>\n<span class=\"line\"><span style=\"color:#032f62\">      &lt;meta name=&quot;viewport&quot; content=&quot;width=device-width, initial-scale=1.0&quot; /&gt;</span></span>\n<span class=\"line\"><span style=\"color:#032f62\">      &lt;link rel=&quot;stylesheet&quot; href=&quot;/styles.css&quot; /&gt;</span></span>\n<span class=\"line\"><span style=\"color:#032f62\">      ${</span><span style=\"color:#6f42c1\">generateHydrationScript</span><span style=\"color:#032f62\">()</span><span style=\"color:#032f62\">}</span></span>\n<span class=\"line\"><span style=\"color:#032f62\">    &lt;/head&gt;</span></span>\n<span class=\"line\"><span style=\"color:#032f62\">    &lt;body&gt;${</span><span style=\"color:#24292e\">app</span><span style=\"color:#032f62\">}&lt;/body&gt;</span></span>\n<span class=\"line\"><span style=\"color:#032f62\">  &lt;/html&gt;</span></span>\n<span class=\"line\"><span style=\"color:#032f62\">`</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span></code></pre><pre class=\"shiki\" style=\"background-color:#fffffe\"><code><span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { HydrationScript } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-js/web&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">App</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#d73a49\">return</span><span style=\"color:#24292e\"> (</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    &lt;</span><span style=\"color:#22863a\">html</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">lang</span><span style=\"color:#d73a49\">=</span><span style=\"color:#032f62\">&quot;en&quot;</span><span style=\"color:#24292e\">&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      &lt;</span><span style=\"color:#22863a\">head</span><span style=\"color:#24292e\">&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        &lt;</span><span style=\"color:#22863a\">title</span><span style=\"color:#24292e\">&gt;🔥 Solid SSR 🔥&lt;/</span><span style=\"color:#22863a\">title</span><span style=\"color:#24292e\">&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        &lt;</span><span style=\"color:#22863a\">meta</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">charset</span><span style=\"color:#d73a49\">=</span><span style=\"color:#032f62\">&quot;UTF-8&quot;</span><span style=\"color:#24292e\"> /&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        &lt;</span><span style=\"color:#22863a\">meta</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">name</span><span style=\"color:#d73a49\">=</span><span style=\"color:#032f62\">&quot;viewport&quot;</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">content</span><span style=\"color:#d73a49\">=</span><span style=\"color:#032f62\">&quot;width=device-width, initial-scale=1.0&quot;</span><span style=\"color:#24292e\"> /&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        &lt;</span><span style=\"color:#22863a\">link</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">rel</span><span style=\"color:#d73a49\">=</span><span style=\"color:#032f62\">&quot;stylesheet&quot;</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">href</span><span style=\"color:#d73a49\">=</span><span style=\"color:#032f62\">&quot;/styles.css&quot;</span><span style=\"color:#24292e\"> /&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        &lt;</span><span style=\"color:#22863a\">HydrationScript</span><span style=\"color:#24292e\"> /&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      &lt;/</span><span style=\"color:#22863a\">head</span><span style=\"color:#24292e\">&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      &lt;</span><span style=\"color:#22863a\">body</span><span style=\"color:#24292e\">&gt;{</span><span style=\"color:#6a737d\">/*... Rest der App*/</span><span style=\"color:#24292e\">}&lt;/</span><span style=\"color:#22863a\">body</span><span style=\"color:#24292e\">&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    &lt;/</span><span style=\"color:#22863a\">html</span><span style=\"color:#24292e\">&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  );</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">};</span></span>\n<span class=\"line\"></span></code></pre><p>Wenn man vom document aus hydriert, kann das Einfügen von Ressourcen, die noch nicht verfübbar sind, Dinge durcheinander bringen. Solid hat dafür eine <code>&lt;NoHydration&gt;</code>-Komponente, deren Kinder ganz normal auf dem Server funktionieren, aber nicht im Browser hydriert werden.</p><pre class=\"shiki\" style=\"background-color:#fffffe\"><code><span class=\"line\"><span style=\"color:#24292e\">&lt;</span><span style=\"color:#22863a\">NoHydration</span><span style=\"color:#24292e\">&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  {manifest.</span><span style=\"color:#6f42c1\">map</span><span style=\"color:#24292e\">((</span><span style=\"color:#e36209\">m</span><span style=\"color:#24292e\">) </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> (</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    &lt;</span><span style=\"color:#22863a\">link</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">rel</span><span style=\"color:#d73a49\">=</span><span style=\"color:#032f62\">&quot;modulepreload&quot;</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">href</span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\">{m.href} /&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  ))}</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">&lt;/</span><span style=\"color:#22863a\">NoHydration</span><span style=\"color:#24292e\">&gt;</span></span>\n<span class=\"line\"></span></code></pre><h2 id=\"asynchrones-und-streaming-ssr\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#asynchrones-und-streaming-ssr\">#</a> Asynchrones und Streaming SSR</h2><p>Diese Mechanismen bauen auf Solids Wissen darüber auf, wie Deine Anwendung funktioniert. Das macht es, indem Suspense und die Resource-API auf dem Server verwendet wird, statt erst die Ressourcen zu laden und dann erst zu rendern. Solid rendert auf dem Server genauso wie auf dem Client. Dein Code und die Ausführungsmuster sind einfach auf die selbe Weise geschrieben.</p><p>Async rendering waits until all Suspense boundaries resolve and then sends the results (or writes them to a file in the case of Static Site Generation).</p><p>Streaming starts flushing synchronous content to the browser immediately rendering your Suspense Fallbacks on the server. Then as the async data finishes on the server it sends the data over the same stream to the client to resolve Suspense where the browser finishes the job and replaces the fallback with real content.</p><p>The advantage of this approach:</p><ul> <li>Server doesn't have to wait for Async data to respond. Assets can start loading sooner in the browser, and the user can start seeing content sooner.</li> <li>Compared to client fetching like JAMStack, data loading starts on the server immediately and doesn't have to wait for client JavaScript to load.</li> <li>All data is serialized and transported from server to client automatically.</li> </ul><h2 id=\"ssr-caveats\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#ssr-caveats\">#</a> SSR Caveats</h2><p>Solids isomorphische SSR-Lösung ist sehr mächtig, so dass man die Anforderungen für beide Umgebungen im gleichen Code ausdrücken kann, der in beiden Umgebungen gleichermaßen läuft. Allerdings führt das zu gewissen Erwartungen in Bezug auf Hydration, vor allem dass der gerenderte View im Client der gleiche ist, der auch auf dem Server gerendert würde. Es muss nicht exakt der gleiche sein, was den Text angeht, aber die Struktur des Markups sollte gleich sein.</p><p>Wir benutzen Markierungen, die vom Server gerendert werden, um Elemente und Ressourcen auf dem Server abzugleichen. Aus diesem Grund sollten Server und Client die gleichen Komponenten haben. Das ist normalerweise kein Problem, da Solid auf die gleiche Art auf dem Server und auf dem Client rendert. Aber derzeit gibt es noch keinen Weg, etwas auf dem Server zu rendern, das nicht auf dem Client hydriert wird. Im Moment gibt es keinen Weg, eine ganze Seite nur partiell zu hydrieren und keine Hydrations-Markierungen dafür zu erzeugen. Es ist alles oder nichts. Partielle Hydration ist etwas, was wir in der Zukunft erforschen wollen.</p><p>Zuletzt müssen alle Ressourcen innerhalb es <code>render</code>-Baums definiert werden. Sie werden dann automatisch serialisiert und im Browser übernommen, aber das funktioniert, weil die <code>render</code>- oder <code>pipeTo</code>-Methoden den Fortschritt des Renderns überblicken, etwas, das wir innerhalb eines isolierten Kontextes nicht können. Ebenso gibt es keine Reaktivität auf dem Server, also können Signale nicht beim initialen Rendern aktualisiert und weiter nach oben im Baum weitergereicht werden. Während es Suspense-Boundaries gibt, funktioniert Solids SSR von oben nach unten.</p><h2 id=\"den-anfang-machen-mit-ssr\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#den-anfang-machen-mit-ssr\">#</a> Den Anfang machen mit SSR</h2><p>SSR-Konfigurationen sind knifflig. Wir haben ein paar Beispiele im Paket <a href=\"https://github.com/solidjs/solid/blob/main/packages/solid-ssr\">solid-ssr</a>.</p><p>Zwischenzeitlich hat die Arbeit an einem neuen Starter begonnen, <a href=\"https://github.com/solidjs/solid-start\">SolidStart</a>, in dem wir versuchen, das Arbeiten damit bequemer zu machen.</p><h2 id=\"den-anfang-mit-statischer-seitengenerierung-machen\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#den-anfang-mit-statischer-seitengenerierung-machen\">#</a> Den Anfang mit statischer Seitengenerierung machen</h2><p><a href=\"https://github.com/solidjs/solid/blob/main/packages/solid-ssr\">solid-ssr</a> hat auch ein Werkzeugt, um statische oder vorgerenderte Seiten zu erzeugen. In der README-Daten finden sich weitere Informationen dazu.</p></section>";
var attributes = {
	title: "Server",
	description: "Eine Erklärung von Solids serverseitigen Fähigkeiten",
	sort: 3
};
var sections = [
	{
		slug: "serverseitiges-rendering",
		title: "Serverseitiges Rendering",
		level: 1,
		children: [
			{
				slug: "hydrations-script",
				title: "Hydrations-Script",
				level: 2,
				children: [
				]
			},
			{
				slug: "asynchrones-und-streaming-ssr",
				title: "Asynchrones und Streaming SSR",
				level: 2,
				children: [
				]
			},
			{
				slug: "ssr-caveats",
				title: "SSR Caveats",
				level: 2,
				children: [
				]
			},
			{
				slug: "den-anfang-machen-mit-ssr",
				title: "Den Anfang machen mit SSR",
				level: 2,
				children: [
				]
			},
			{
				slug: "den-anfang-mit-statischer-seitengenerierung-machen",
				title: "Den Anfang mit statischer Seitengenerierung machen",
				level: 2,
				children: [
				]
			}
		]
	}
];
var server = {
	html: html,
	attributes: attributes,
	sections: sections
};

export { attributes, server as default, html, sections };
