var html = "<section class=\"mt-10\"><h1 id=\"testing-solid\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#testing-solid\">#</a> Testing Solid</h1><p>To use your Solid code in production, it needs to be tested. Since you don't want to test everything manually, you need automated tests. Testing Solid code can be simple, once you got everything set up and know a few useful patterns for testing.</p><h2 id=\"testing-setup\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#testing-setup\">#</a> Testing Setup</h2><p>Before you set up testing, you need to choose your test runner. There is an abundance of choices, but we'll focus on two very different projects that are opposite extremes, jest and uvu. Jest is heavily integrated, uvu only brings the bare necessities. If you want to use another test runner, the setup for uvu should work for most other test runners.</p><h3 id=\"setting-up-jest\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#setting-up-jest\">#</a> Setting up Jest</h3><p>Unfortunately, integrated though it may be, jest will not support esm or typescript out of the box, but needs its transformer configuration set up.</p><p>The main options are solid-jest, which uses babel to transform the Solid code, omitting type checks on testing if TypeScript is used, and ts-jest, which uses the TypeScript compiler and checks the types within the tests.</p><p>If you are not using TypeScript, use solid-jest, otherwise choose if you want to check for types while running your tests or not.</p><h4 id=\"using-solid-jest\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#using-solid-jest\">#</a> Using solid-jest</h4><p>Install the required dependencies:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#d73a49\">&gt;</span><span style=\"color:#24292e\"> npm i --save-dev jest solid-jest </span><span style=\"color:#6a737d\"># or yarn add -D or pnpm</span></span>\n<span class=\"line\"></span></code></pre><p>Or for TypeScript:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#d73a49\">&gt;</span><span style=\"color:#24292e\"> npm i --save-dev jest solid-jest @types/jest </span><span style=\"color:#6a737d\"># or yarn add -D or pnpm</span></span>\n<span class=\"line\"></span></code></pre><p>Next, you need to define your <code>.babelrc</code> if you haven't already done so:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#24292e\">{</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#032f62\">&quot;presets&quot;</span><span style=\"color:#24292e\">: [</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#032f62\">&quot;@babel/preset-env&quot;</span><span style=\"color:#24292e\">,</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#032f62\">&quot;babel-preset-solid&quot;</span><span style=\"color:#24292e\">,</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// only if you use TS with solid-jest</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#032f62\">&quot;@babel/preset-typescript&quot;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  ]</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">}</span></span>\n<span class=\"line\"></span></code></pre><p>And amend your <code>package.json</code> so that it looks like this:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#24292e\">{</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#032f62\">&quot;scripts&quot;</span><span style=\"color:#24292e\">: {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// your other scripts go here</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#032f62\">&quot;test&quot;</span><span style=\"color:#24292e\">: </span><span style=\"color:#032f62\">&quot;jest&quot;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  },</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#032f62\">&quot;jest&quot;</span><span style=\"color:#24292e\">: {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#032f62\">&quot;preset&quot;</span><span style=\"color:#24292e\">: </span><span style=\"color:#032f62\">&quot;solid-jest/preset/browser&quot;</span><span style=\"color:#24292e\">,</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// insert setupFiles and other config</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  }</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">}</span></span>\n<span class=\"line\"></span></code></pre><h4 id=\"using-ts-jest\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#using-ts-jest\">#</a> Using ts-jest</h4><p>To use ts-jest, you need first to install it:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#d73a49\">&gt;</span><span style=\"color:#24292e\"> npm i --save-dev jest ts-jest @types/jest </span><span style=\"color:#6a737d\"># or yarn add -D or pnpm</span></span>\n<span class=\"line\"></span></code></pre><p>And then configure it in <code>package.json</code>:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#24292e\">{ </span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#032f62\">&quot;scripts&quot;</span><span style=\"color:#24292e\">: {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// your other scripts go here</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#032f62\">&quot;test&quot;</span><span style=\"color:#24292e\">: </span><span style=\"color:#032f62\">&quot;jest&quot;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  },</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#032f62\">&quot;jest&quot;</span><span style=\"color:#24292e\">: {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#032f62\">&quot;preset&quot;</span><span style=\"color:#24292e\">: </span><span style=\"color:#032f62\">&quot;ts-jest&quot;</span><span style=\"color:#24292e\">,</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#032f62\">&quot;globals&quot;</span><span style=\"color:#24292e\">: {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#032f62\">&quot;ts-jest&quot;</span><span style=\"color:#24292e\">: {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        </span><span style=\"color:#032f62\">&quot;tsconfig&quot;</span><span style=\"color:#24292e\">: </span><span style=\"color:#032f62\">&quot;tsconfig.json&quot;</span><span style=\"color:#24292e\">,</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        </span><span style=\"color:#032f62\">&quot;babelConfig&quot;</span><span style=\"color:#24292e\">: {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">          </span><span style=\"color:#032f62\">&quot;presets&quot;</span><span style=\"color:#24292e\">: [</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">            </span><span style=\"color:#032f62\">&quot;babel-preset-solid&quot;</span><span style=\"color:#24292e\">,</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">            </span><span style=\"color:#032f62\">&quot;@babel/preset-env&quot;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">          ]</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        }</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      }</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    },</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// insert setupFiles and other config</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// you probably want to test in browser mode:</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#032f62\">&quot;testEnvironment&quot;</span><span style=\"color:#24292e\">: </span><span style=\"color:#032f62\">&quot;jsdom&quot;</span><span style=\"color:#24292e\">,</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// unfortunately, solid cannot detect browser mode here,</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// so we need to manually point it to the right versions:</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#032f62\">&quot;moduleNameMapper&quot;</span><span style=\"color:#24292e\">: {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#032f62\">&quot;solid-js/web&quot;</span><span style=\"color:#24292e\">: </span><span style=\"color:#032f62\">&quot;&lt;rootDir&gt;/node_modules/solid-js/web/dist/web.cjs&quot;</span><span style=\"color:#24292e\">,</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#032f62\">&quot;solid-js&quot;</span><span style=\"color:#24292e\">: </span><span style=\"color:#032f62\">&quot;&lt;rootDir&gt;/node_modules/solid-js/dist/solid.cjs&quot;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    }</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// windows users have to replace &quot;/&quot; with &quot;\\&quot;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  }</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">}</span></span>\n<span class=\"line\"></span></code></pre><h3 id=\"typescript-and-jest\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#typescript-and-jest\">#</a> TypeScript and Jest</h3><p>Since jest is injecting its testing facilities into the global scope, you need to load its types into tsconfig.json to satisfy the typescript compiler:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#24292e\">{</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6a737d\">// part of tsconfig.json</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#032f62\">&quot;types&quot;</span><span style=\"color:#24292e\">: [</span><span style=\"color:#032f62\">&quot;jest&quot;</span><span style=\"color:#24292e\">]</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">}</span></span>\n<span class=\"line\"></span></code></pre><p>This requires the installation of <code>@types/jest</code> as mentioned before.</p><h3 id=\"setting-up-uvu\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#setting-up-uvu\">#</a> Setting up uvu</h3><p>First, you need to install the required packages:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#d73a49\">&gt;</span><span style=\"color:#24292e\"> npm i --save-dev uvu solid-register jsdom </span><span style=\"color:#6a737d\"># or yarn add -D or pnpm</span></span>\n<span class=\"line\"></span></code></pre><p>Then setup your test script in <code>package.json</code>:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#d73a49\">&gt;</span><span style=\"color:#24292e\"> npm set-script </span><span style=\"color:#005cc5\">test</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;uvu -r solid-register&quot;</span></span>\n<span class=\"line\"></span></code></pre><p>Additional setup files can be added via <code>-r setup.ts</code>, ignore non-tests with <code>-i not-a-test.test.ts</code>.</p><h3 id=\"coverage-reports\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#coverage-reports\">#</a> Coverage Reports</h3><p>If you want to check code coverage of your tests, the favorite tool for uvu is c8. To install and set it up, run:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#d73a49\">&gt;</span><span style=\"color:#24292e\"> npm i --save-dev c8 </span><span style=\"color:#6a737d\"># or yarn add -D or pnpm</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">&gt;</span><span style=\"color:#24292e\"> npm set-script </span><span style=\"color:#032f62\">&quot;test:coverage&quot;</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;c8 uvu -r solid-register&quot;</span></span>\n<span class=\"line\"></span></code></pre><p>Now if you <code>npm run test:coverage</code>, you'll see the test coverage.</p><p>If you want nice HTML coverage reports, you</p><h3 id=\"watch-mode\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#watch-mode\">#</a> Watch Mode</h3><p>Neither <code>uvu</code> nor <code>tape</code> have a watch mode out of the box, but you can use <code>chokidar-cli</code> to do the same:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#d73a49\">&gt;</span><span style=\"color:#24292e\"> npm i --save-dev chokidar-cli </span><span style=\"color:#6a737d\"># or yarn add -D or pnpm</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">&gt;</span><span style=\"color:#24292e\"> npm set-script </span><span style=\"color:#032f62\">&quot;test:watch&quot;</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;chokidar src/**/*.ts src/**/*.tsx -c </span><span style=\"color:#005cc5\">\\&quot;</span><span style=\"color:#032f62\">uvu -r solid-register</span><span style=\"color:#005cc5\">\\&quot;</span></span>\n<span class=\"line\"><span style=\"color:#032f62\"># use .js/.jsx instead of .ts/.tsx</span></span>\n<span class=\"line\"></span></code></pre><p>Now if you run <code>npm run test:watch</code>, the tests will run every time you change a file.</p><h3 id=\"solid-testing-library\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#solid-testing-library\">#</a> solid-testing-library</h3><p>If you want to test components, you should definitely install <code>solid-testing-library</code>:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#d73a49\">&gt;</span><span style=\"color:#24292e\"> npm i --save-dev solid-testing-library </span><span style=\"color:#6a737d\"># or yarn add -D or pnpm</span></span>\n<span class=\"line\"></span></code></pre><p>This allows you to render your components, fire events and select elements from a user's perspective.</p><h3 id=\"%40testing-library%2Fjest-dom\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#%40testing-library%2Fjest-dom\">#</a> @testing-library/jest-dom</h3><p>If you are using jest, <code>solid-testing-library</code> works very well with <code>@testing-library/jest-dom</code>:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#d73a49\">&gt;</span><span style=\"color:#24292e\"> npm i --save-dev @testing-library/jest-dom </span><span style=\"color:#6a737d\"># or yarn add -D or pnpm</span></span>\n<span class=\"line\"></span></code></pre><p>And import the extensions to expect in a setup file:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#6a737d\">// test/jest-setup.ts</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&#39;@testing-library/jest-dom/extend-expect&#39;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span></code></pre><p>And load that in jest using the following entry in package.json:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#24292e\">{</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#032f62\">&quot;jest&quot;</span><span style=\"color:#24292e\">: {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// your other settings here</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    setupFiles: [</span><span style=\"color:#032f62\">&quot;@testing-library/jest-dom/extend-expect&quot;</span><span style=\"color:#24292e\">, </span><span style=\"color:#032f62\">&quot;regenerator-runtime&quot;</span><span style=\"color:#24292e\">]</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  }</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">}</span></span>\n<span class=\"line\"></span></code></pre><p>Also don't forget to include the types in <code>tsconfig.json</code>:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#24292e\">{</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6a737d\">// part of tsconfig.json</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#032f62\">&quot;types&quot;</span><span style=\"color:#24292e\">: [</span><span style=\"color:#032f62\">&quot;jest&quot;</span><span style=\"color:#24292e\">, </span><span style=\"color:#032f62\">&quot;@testing-library/jest-dom&quot;</span><span style=\"color:#24292e\">]</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">}</span></span>\n<span class=\"line\"></span></code></pre><h3 id=\"solid-dom-testing\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#solid-dom-testing\">#</a> solid-dom-testing</h3><p>If you are using another test runner, e.g. uvu or tape, there are a few assertion helpers in <code>solid-dom-testing</code> that support similar assertions:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#d73a49\">&gt;</span><span style=\"color:#24292e\"> npm i --save-dev solid-dom-testing </span><span style=\"color:#6a737d\"># or yarn add -D or pnpm</span></span>\n<span class=\"line\"></span></code></pre><p>There's no setup required, you can just import and use the helpers in your tests as you see fit.</p><h2 id=\"testing-patterns-and-best-practices\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#testing-patterns-and-best-practices\">#</a> Testing Patterns and Best Practices</h2><p>Now that you have installed your testing tools, you should start to use them. In order to make this easier, solid supports a few nice patterns.</p><h3 id=\"testing-reactive-state\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#testing-reactive-state\">#</a> Testing Reactive State</h3><p>You may want to keep parts of your state separate from the components for ease of maintenance or being able to support multiple views. In this case, the interface against which you are testing is the state itself. Keep in mind that out of a <a href=\"https://www.solidjs.com/docs/latest/api#createroot\">reactive root</a> your state is not tracked and updates won't trigger effects and memos.</p><p>Also, since effects trigger asynchronously, it can help to wrap our assertions in a final effect. Alternatively, to observe a sequence of effects over multiple changes, it can help to return the necessary tools from <code>createRoot</code> and execute them in an async test function (as <code>createRoot</code> itself cannot take an <code>async</code> function).</p><p>As an example, let's test <code>createLocalStorage</code> from the <a href=\"https://www.solidjs.com/examples/todos\">todo example</a>:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { createEffect } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-js&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { createStore, Store, SetStoreFunction } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-js/store&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#d73a49\">export</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">function</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createLocalStore</span><span style=\"color:#24292e\">&lt;</span><span style=\"color:#e36209\">T</span><span style=\"color:#24292e\">&gt;(</span><span style=\"color:#e36209\">initState</span><span style=\"color:#d73a49\">:</span><span style=\"color:#24292e\"> </span><span style=\"color:#e36209\">T</span><span style=\"color:#24292e\">)</span><span style=\"color:#d73a49\">:</span><span style=\"color:#24292e\"> [</span><span style=\"color:#e36209\">Store</span><span style=\"color:#24292e\">&lt;</span><span style=\"color:#e36209\">T</span><span style=\"color:#24292e\">&gt;, </span><span style=\"color:#e36209\">SetStoreFunction</span><span style=\"color:#24292e\">&lt;</span><span style=\"color:#e36209\">T</span><span style=\"color:#24292e\">&gt;] {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">\t</span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> [</span><span style=\"color:#005cc5\">state</span><span style=\"color:#24292e\">, </span><span style=\"color:#005cc5\">setState</span><span style=\"color:#24292e\">] </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createStore</span><span style=\"color:#24292e\">(initState);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">\t</span><span style=\"color:#d73a49\">if</span><span style=\"color:#24292e\"> (localStorage.todos) </span><span style=\"color:#6f42c1\">setState</span><span style=\"color:#24292e\">(</span><span style=\"color:#005cc5\">JSON</span><span style=\"color:#24292e\">.</span><span style=\"color:#005cc5\">parse</span><span style=\"color:#24292e\">(localStorage.todos));</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">\t</span><span style=\"color:#6f42c1\">createEffect</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> (localStorage.todos </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">JSON</span><span style=\"color:#24292e\">.</span><span style=\"color:#005cc5\">stringify</span><span style=\"color:#24292e\">(state)));</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">\t</span><span style=\"color:#d73a49\">return</span><span style=\"color:#24292e\"> [state, setState];</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">}</span></span>\n<span class=\"line\"></span></code></pre><p>Instead of creating a TODO component, we can test this model in isolation; when we do that, we need to keep in mind that 1. reactive changes only work when they have a tracking context provided by <code>render</code> or <code>createRoot</code> and 2. are asynchronous, but we can use <code>createEffect</code> to catch them. Using <code>createRoot</code> has the advantage that we can trigger the disposal manually:</p><h4 id=\"testing-in-jest\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#testing-in-jest\">#</a> Testing in Jest</h4><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { createLocalStore } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;./main.tsx&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { createRoot, createEffect } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-js&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6f42c1\">describe</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;createLocalStore&quot;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">beforeEach</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> { </span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    localStorage.</span><span style=\"color:#6f42c1\">removeItem</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;todos&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  });</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">initialState</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    todos: [],</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    newTitle: </span><span style=\"color:#032f62\">&quot;&quot;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  };</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">test</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;it reads pre-existing state from localStorage&quot;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createRoot</span><span style=\"color:#24292e\">(</span><span style=\"color:#e36209\">dispose</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">savedState</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> { todos: [], newTitle: </span><span style=\"color:#032f62\">&quot;saved&quot;</span><span style=\"color:#24292e\"> };</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    localStorage.</span><span style=\"color:#6f42c1\">setItem</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;todos&quot;</span><span style=\"color:#24292e\">, </span><span style=\"color:#005cc5\">JSON</span><span style=\"color:#24292e\">.</span><span style=\"color:#005cc5\">stringify</span><span style=\"color:#24292e\">(savedState));</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> [</span><span style=\"color:#005cc5\">state</span><span style=\"color:#24292e\">] </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createLocalStore</span><span style=\"color:#24292e\">(initialState);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">expect</span><span style=\"color:#24292e\">(state).</span><span style=\"color:#6f42c1\">toEqual</span><span style=\"color:#24292e\">(savedState);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">dispose</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  }));</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">test</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;it stores new state to localStorage&quot;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createRoot</span><span style=\"color:#24292e\">(</span><span style=\"color:#e36209\">dispose</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> [</span><span style=\"color:#005cc5\">state</span><span style=\"color:#24292e\">, </span><span style=\"color:#005cc5\">setState</span><span style=\"color:#24292e\">] </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createLocalStore</span><span style=\"color:#24292e\">(initialState);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">setState</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;newTitle&quot;</span><span style=\"color:#24292e\">, </span><span style=\"color:#032f62\">&quot;updated&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// to catch an effect, use an effect</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">return</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">new</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">Promise</span><span style=\"color:#24292e\">&lt;</span><span style=\"color:#005cc5\">void</span><span style=\"color:#24292e\">&gt;((</span><span style=\"color:#e36209\">resolve</span><span style=\"color:#24292e\">) </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createEffect</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#6f42c1\">expect</span><span style=\"color:#24292e\">(</span><span style=\"color:#005cc5\">JSON</span><span style=\"color:#24292e\">.</span><span style=\"color:#005cc5\">parse</span><span style=\"color:#24292e\">(localStorage.todos </span><span style=\"color:#d73a49\">||</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;&quot;</span><span style=\"color:#24292e\">))</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        .</span><span style=\"color:#6f42c1\">toEqual</span><span style=\"color:#24292e\">({ todos: [], newTitle: </span><span style=\"color:#032f62\">&quot;updated&quot;</span><span style=\"color:#24292e\"> });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#6f42c1\">dispose</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#6f42c1\">resolve</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    }));</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  }));</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">test</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;it updates state multiple times&quot;</span><span style=\"color:#24292e\">, </span><span style=\"color:#d73a49\">async</span><span style=\"color:#24292e\"> () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> {</span><span style=\"color:#005cc5\">dispose</span><span style=\"color:#24292e\">, </span><span style=\"color:#005cc5\">setState</span><span style=\"color:#24292e\">} </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createRoot</span><span style=\"color:#24292e\">(</span><span style=\"color:#e36209\">dispose</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> [</span><span style=\"color:#005cc5\">state</span><span style=\"color:#24292e\">, </span><span style=\"color:#005cc5\">setState</span><span style=\"color:#24292e\">] </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createLocalStore</span><span style=\"color:#24292e\">(initialState);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#d73a49\">return</span><span style=\"color:#24292e\"> {dispose, setState};</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">setState</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;newTitle&quot;</span><span style=\"color:#24292e\">, </span><span style=\"color:#032f62\">&quot;first&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// wait a tick to resolve all effects</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">await</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">new</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">Promise</span><span style=\"color:#24292e\">((</span><span style=\"color:#e36209\">done</span><span style=\"color:#24292e\">) </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">setTimeout</span><span style=\"color:#24292e\">(done, </span><span style=\"color:#005cc5\">0</span><span style=\"color:#24292e\">));</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">expect</span><span style=\"color:#24292e\">(</span><span style=\"color:#005cc5\">JSON</span><span style=\"color:#24292e\">.</span><span style=\"color:#005cc5\">parse</span><span style=\"color:#24292e\">(localStorage.todos </span><span style=\"color:#d73a49\">||</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;&quot;</span><span style=\"color:#24292e\">))</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      .</span><span style=\"color:#6f42c1\">toEqual</span><span style=\"color:#24292e\">({ todos: [], newTitle: </span><span style=\"color:#032f62\">&quot;first&quot;</span><span style=\"color:#24292e\"> });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">setState</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;newTitle&quot;</span><span style=\"color:#24292e\">, </span><span style=\"color:#032f62\">&quot;second&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">await</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">new</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">Promise</span><span style=\"color:#24292e\">((</span><span style=\"color:#e36209\">done</span><span style=\"color:#24292e\">) </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">setTimeout</span><span style=\"color:#24292e\">(done, </span><span style=\"color:#005cc5\">0</span><span style=\"color:#24292e\">));</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">expect</span><span style=\"color:#24292e\">(</span><span style=\"color:#005cc5\">JSON</span><span style=\"color:#24292e\">.</span><span style=\"color:#005cc5\">parse</span><span style=\"color:#24292e\">(localStorage.todos </span><span style=\"color:#d73a49\">||</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;&quot;</span><span style=\"color:#24292e\">))</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      .</span><span style=\"color:#6f42c1\">toEqual</span><span style=\"color:#24292e\">({ todos: [], newTitle: </span><span style=\"color:#032f62\">&quot;first&quot;</span><span style=\"color:#24292e\"> });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">dispose</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">});</span></span>\n<span class=\"line\"></span></code></pre><h4 id=\"testing-in-uvu\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#testing-in-uvu\">#</a> Testing in uvu</h4><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { createLocalStore } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;./main&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { suite } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;uvu&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">*</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">as</span><span style=\"color:#24292e\"> assert </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;uvu/assert&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { createEffect, createRoot } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-js&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">todoTest</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">suite</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;createLocalStore&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">todoTest.before.</span><span style=\"color:#6f42c1\">each</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> { </span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  localStorage.</span><span style=\"color:#6f42c1\">removeItem</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;todos&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">});</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">initialState</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  todos: [],</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  newTitle: </span><span style=\"color:#032f62\">&quot;&quot;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">};</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6f42c1\">todoTest</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;it reads pre-existing state from localStorage&quot;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> </span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">createRoot</span><span style=\"color:#24292e\">(</span><span style=\"color:#e36209\">dispose</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">savedState</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> { todos: [], newTitle: </span><span style=\"color:#032f62\">&quot;saved&quot;</span><span style=\"color:#24292e\"> };</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    localStorage.</span><span style=\"color:#6f42c1\">setItem</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;todos&quot;</span><span style=\"color:#24292e\">, </span><span style=\"color:#005cc5\">JSON</span><span style=\"color:#24292e\">.</span><span style=\"color:#005cc5\">stringify</span><span style=\"color:#24292e\">(savedState));</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> [</span><span style=\"color:#005cc5\">state</span><span style=\"color:#24292e\">] </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createLocalStore</span><span style=\"color:#24292e\">(initialState);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    assert.</span><span style=\"color:#6f42c1\">equal</span><span style=\"color:#24292e\">(state, savedState);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">dispose</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  }));</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6f42c1\">todoTest</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;it stores new state to localStorage&quot;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">createRoot</span><span style=\"color:#24292e\">(</span><span style=\"color:#e36209\">dispose</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> [</span><span style=\"color:#005cc5\">_</span><span style=\"color:#24292e\">, </span><span style=\"color:#005cc5\">setState</span><span style=\"color:#24292e\">] </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createLocalStore</span><span style=\"color:#24292e\">(initialState);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">setState</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;newTitle&quot;</span><span style=\"color:#24292e\">, </span><span style=\"color:#032f62\">&quot;updated&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// to catch an effect, we need an effect</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">return</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">new</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">Promise</span><span style=\"color:#24292e\">&lt;</span><span style=\"color:#005cc5\">void</span><span style=\"color:#24292e\">&gt;((</span><span style=\"color:#e36209\">resolve</span><span style=\"color:#24292e\">) </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createEffect</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      assert.</span><span style=\"color:#6f42c1\">equal</span><span style=\"color:#24292e\">(</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        </span><span style=\"color:#005cc5\">JSON</span><span style=\"color:#24292e\">.</span><span style=\"color:#005cc5\">parse</span><span style=\"color:#24292e\">(localStorage.todos </span><span style=\"color:#d73a49\">||</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;&quot;</span><span style=\"color:#24292e\">),</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        { todos: [], newTitle: </span><span style=\"color:#032f62\">&quot;updated&quot;</span><span style=\"color:#24292e\"> }</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      );</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#6f42c1\">dispose</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#6f42c1\">resolve</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    }));</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  }));</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">todoTest.</span><span style=\"color:#6f42c1\">run</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"></span></code></pre><h3 id=\"testing-directives\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#testing-directives\">#</a> Testing directives</h3><p><a href=\"https://www.solidjs.com/docs/latest/api#use%3A___\">Directives</a> allow using refs in a reusable way. They are basically functions that follow the pattern <code>(ref: HTMLElement, data: Accessor&lt;any&gt;) =&gt; void</code>. In our <a href=\"https://www.solidjs.com/tutorial/bindings_directives?solved\">directives tutorial</a>, we define the <code>clickOutside</code> directive that should call the callback wrapped in the accessor argument.</p><p>We could now create a component and use the directive in there, but then we'd be testing the use of directives instead of directly testing the directive. It's simpler to test the surface of the directive by providing a mounted node and the accessor:</p><h4 id=\"testing-in-jest-1\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#testing-in-jest-1\">#</a> Testing in Jest</h4><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#6a737d\">// click-outside.test.ts</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> clickOutside </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;click-outside&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { createRoot } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-js&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { fireEvent } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-testing-library&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6f42c1\">describe</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;clickOutside&quot;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">ref</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> document.</span><span style=\"color:#6f42c1\">createElement</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;div&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">beforeAll</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    document.body.</span><span style=\"color:#6f42c1\">appendChild</span><span style=\"color:#24292e\">(ref);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  });</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">afterAll</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    document.body.</span><span style=\"color:#6f42c1\">removeChild</span><span style=\"color:#24292e\">(ref);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  });</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">test</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;will trigger on click outside&quot;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createRoot</span><span style=\"color:#24292e\">((</span><span style=\"color:#e36209\">dispose</span><span style=\"color:#24292e\">) </span><span style=\"color:#d73a49\">=&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">new</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">Promise</span><span style=\"color:#24292e\">&lt;</span><span style=\"color:#005cc5\">void</span><span style=\"color:#24292e\">&gt;((</span><span style=\"color:#e36209\">resolve</span><span style=\"color:#24292e\">) </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#d73a49\">let</span><span style=\"color:#24292e\"> clickedOutside </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">false</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#6f42c1\">clickOutside</span><span style=\"color:#24292e\">(ref, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> { clickedOutside </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">true</span><span style=\"color:#24292e\">; });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      document.body.</span><span style=\"color:#6f42c1\">addEventListener</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;click&quot;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        </span><span style=\"color:#6f42c1\">expect</span><span style=\"color:#24292e\">(clickedOutside).</span><span style=\"color:#6f42c1\">toBeTruthy</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        </span><span style=\"color:#6f42c1\">dispose</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        </span><span style=\"color:#6f42c1\">resolve</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      fireEvent.</span><span style=\"color:#6f42c1\">click</span><span style=\"color:#24292e\">(document.body);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    })</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  ));</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">test</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;will not trigger on click inside&quot;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createRoot</span><span style=\"color:#24292e\">((</span><span style=\"color:#e36209\">dispose</span><span style=\"color:#24292e\">) </span><span style=\"color:#d73a49\">=&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">new</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">Promise</span><span style=\"color:#24292e\">&lt;</span><span style=\"color:#005cc5\">void</span><span style=\"color:#24292e\">&gt;((</span><span style=\"color:#e36209\">resolve</span><span style=\"color:#24292e\">) </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#d73a49\">let</span><span style=\"color:#24292e\"> clickedOutside </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">false</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#6f42c1\">clickOutside</span><span style=\"color:#24292e\">(ref, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> { clickedOutside </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">true</span><span style=\"color:#24292e\">; });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      ref.</span><span style=\"color:#6f42c1\">addEventListener</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;click&quot;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        </span><span style=\"color:#6f42c1\">expect</span><span style=\"color:#24292e\">(clickedOutside).</span><span style=\"color:#6f42c1\">toBeFalsy</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        </span><span style=\"color:#6f42c1\">dispose</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">        </span><span style=\"color:#6f42c1\">resolve</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      fireEvent.</span><span style=\"color:#6f42c1\">click</span><span style=\"color:#24292e\">(ref);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    })</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  ));</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">});</span></span>\n<span class=\"line\"></span></code></pre><h4 id=\"testing-in-uvu-1\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#testing-in-uvu-1\">#</a> Testing in uvu</h4><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#6a737d\">// click-outside.test.ts</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> clickOutside </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&#39;click-outside.tsx&#39;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { createRoot } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&#39;solid-js&#39;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { fireEvent } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&#39;solid-testing-library&#39;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">clickTest</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">suite</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&#39;clickOutside&#39;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">ref</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> document.</span><span style=\"color:#6f42c1\">createElement</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&#39;div&#39;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span></span>\n<span class=\"line\"><span style=\"color:#24292e\">clickTest.</span><span style=\"color:#6f42c1\">before</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  document.body.</span><span style=\"color:#6f42c1\">appendChild</span><span style=\"color:#24292e\">(ref);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">});</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">clickTest.</span><span style=\"color:#6f42c1\">after</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  document.body.</span><span style=\"color:#6f42c1\">removeChild</span><span style=\"color:#24292e\">(ref);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">});</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6f42c1\">clickTest</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&#39;will trigger on click outside&#39;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createRoot</span><span style=\"color:#24292e\">((</span><span style=\"color:#e36209\">dispose</span><span style=\"color:#24292e\">) </span><span style=\"color:#d73a49\">=&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#d73a49\">new</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">Promise</span><span style=\"color:#24292e\">&lt;</span><span style=\"color:#005cc5\">void</span><span style=\"color:#24292e\">&gt;((</span><span style=\"color:#e36209\">resolve</span><span style=\"color:#24292e\">) </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">let</span><span style=\"color:#24292e\"> clickedOutside </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">false</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">clickOutside</span><span style=\"color:#24292e\">(ref, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> { clickedOutside </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">true</span><span style=\"color:#24292e\">; });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    document.body.</span><span style=\"color:#6f42c1\">addEventListener</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&#39;click&#39;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      assert.</span><span style=\"color:#6f42c1\">ok</span><span style=\"color:#24292e\">(clickedOutside);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#6f42c1\">dispose</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#6f42c1\">resolve</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    fireEvent.</span><span style=\"color:#6f42c1\">click</span><span style=\"color:#24292e\">(document.body);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  })</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">));</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6f42c1\">clickTest</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&#39;will not trigger on click inside&#39;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createRoot</span><span style=\"color:#24292e\">((</span><span style=\"color:#e36209\">dispose</span><span style=\"color:#24292e\">) </span><span style=\"color:#d73a49\">=&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#d73a49\">new</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">Promise</span><span style=\"color:#24292e\">&lt;</span><span style=\"color:#005cc5\">void</span><span style=\"color:#24292e\">&gt;((</span><span style=\"color:#e36209\">resolve</span><span style=\"color:#24292e\">) </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">let</span><span style=\"color:#24292e\"> clickedOutside </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">false</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">clickOutside</span><span style=\"color:#24292e\">(ref, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> { clickedOutside </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">true</span><span style=\"color:#24292e\">; });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    ref.</span><span style=\"color:#6f42c1\">addEventListener</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&#39;click&#39;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      assert.</span><span style=\"color:#6f42c1\">is</span><span style=\"color:#24292e\">(clickedOutside, </span><span style=\"color:#005cc5\">false</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#6f42c1\">dispose</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">      </span><span style=\"color:#6f42c1\">resolve</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    fireEvent.</span><span style=\"color:#6f42c1\">click</span><span style=\"color:#24292e\">(ref);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  })</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">));</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">clickTest.</span><span style=\"color:#6f42c1\">run</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"></span></code></pre><h3 id=\"testing-components\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#testing-components\">#</a> Testing components</h3><p>Let's take a very simple click-counter component that we want to test:</p><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#6a737d\">// main.tsx</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { createSignal, Component } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-js&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#d73a49\">export</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">Counter</span><span style=\"color:#d73a49\">:</span><span style=\"color:#24292e\"> </span><span style=\"color:#e36209\">Component</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> [</span><span style=\"color:#005cc5\">count</span><span style=\"color:#24292e\">, </span><span style=\"color:#005cc5\">setCount</span><span style=\"color:#24292e\">] </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">createSignal</span><span style=\"color:#24292e\">(</span><span style=\"color:#005cc5\">0</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#d73a49\">return</span><span style=\"color:#24292e\"> &lt;</span><span style=\"color:#e36209\">div</span><span style=\"color:#24292e\"> </span><span style=\"color:#e36209\">role</span><span style=\"color:#24292e\">=</span><span style=\"color:#032f62\">&quot;button&quot;</span><span style=\"color:#24292e\"> </span><span style=\"color:#e36209\">onClick</span><span style=\"color:#24292e\">={() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> </span><span style=\"color:#e36209\">setCount</span><span style=\"color:#24292e\">(</span><span style=\"color:#e36209\">c</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> c </span><span style=\"color:#d73a49\">+</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">1</span><span style=\"color:#24292e\">)}&gt;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#e36209\">Count</span><span style=\"color:#24292e\">: {</span><span style=\"color:#6f42c1\">count</span><span style=\"color:#24292e\">()}</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#d73a49\">&lt;/</span><span style=\"color:#24292e\">div</span><span style=\"color:#d73a49\">&gt;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">}</span></span>\n<span class=\"line\"></span></code></pre><p>You should definitely install <code>solid-testing-library</code>, if you haven't already done that; it's most important helpers are <code>render</code> to render a component to the dom in a managed way, <code>fireEvent</code> to dispatch events in a way that resembles actual user events and <code>screen</code> to provide global selectors. If you use jest, you should also install <code>@testing-library/jest-dom</code> and set it up to have some helpful assertions, otherwise install <code>solid-dom-testing</code> as described above.</p><h4 id=\"testing-in-jest-2\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#testing-in-jest-2\">#</a> Testing in Jest</h4><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#6a737d\">// main.test.tsx</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { Counter } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;./main&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { cleanup, fireEvent, render, screen } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-testing-library&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6f42c1\">describe</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;Counter&quot;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">afterEach</span><span style=\"color:#24292e\">(cleanup);</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">test</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;it starts with zero&quot;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">render</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> &lt;</span><span style=\"color:#e36209\">Counter</span><span style=\"color:#24292e\"> /&gt;);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">button</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> screen.</span><span style=\"color:#6f42c1\">getByRole</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;button&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">expect</span><span style=\"color:#24292e\">(button).</span><span style=\"color:#6f42c1\">toBeInTheDocument</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">expect</span><span style=\"color:#24292e\">(button).</span><span style=\"color:#6f42c1\">toHaveTextContent</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;Count: 0&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  });</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">test</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;it increases its value on click&quot;</span><span style=\"color:#24292e\">, </span><span style=\"color:#d73a49\">async</span><span style=\"color:#24292e\"> () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">render</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> &lt;</span><span style=\"color:#e36209\">Counter</span><span style=\"color:#24292e\"> /&gt;);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">button</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> screen.</span><span style=\"color:#6f42c1\">getByRole</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;button&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    fireEvent.</span><span style=\"color:#6f42c1\">click</span><span style=\"color:#24292e\">(button);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6a737d\">// the event loop takes one Promise to resolve to be finished</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">await</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">Promise</span><span style=\"color:#24292e\">.</span><span style=\"color:#6f42c1\">resolve</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">expect</span><span style=\"color:#24292e\">(button).</span><span style=\"color:#6f42c1\">toHaveTextContent</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;Count: 1&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    fireEvent.</span><span style=\"color:#6f42c1\">click</span><span style=\"color:#24292e\">(button);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#d73a49\">await</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">Promise</span><span style=\"color:#24292e\">.</span><span style=\"color:#6f42c1\">resolve</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">    </span><span style=\"color:#6f42c1\">expect</span><span style=\"color:#24292e\">(button).</span><span style=\"color:#6f42c1\">toHaveTextContent</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;Count: 2&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  });</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">});</span></span>\n<span class=\"line\"></span></code></pre><h4 id=\"testing-in-uvu-2\" tabindex=\"-1\"><a class=\"header-anchor\" href=\"#testing-in-uvu-2\">#</a> Testing in uvu</h4><pre class=\"shiki\" style=\"background-color:#bbb\"><code><span class=\"line\"><span style=\"color:#6a737d\">// main.test.tsx</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { suite } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;uvu&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">*</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">as</span><span style=\"color:#24292e\"> assert </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;uvu/assert&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { Counter } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;main&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { fireEvent, render, screen } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-testing-library&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"><span style=\"color:#d73a49\">import</span><span style=\"color:#24292e\"> { isInDocument, hasTextContent } </span><span style=\"color:#d73a49\">from</span><span style=\"color:#24292e\"> </span><span style=\"color:#032f62\">&quot;solid-dom-testing&quot;</span><span style=\"color:#24292e\">;</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">testCounter</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">suite</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;Counter&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">testCounter.after.</span><span style=\"color:#6f42c1\">each</span><span style=\"color:#24292e\">(cleanup);</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6f42c1\">testCounter</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;it starts with zero&quot;</span><span style=\"color:#24292e\">, () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> { </span><span style=\"color:#005cc5\">getByRole</span><span style=\"color:#24292e\"> } </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">render</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> &lt;</span><span style=\"color:#e36209\">Counter</span><span style=\"color:#24292e\"> /&gt;);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">button</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> </span><span style=\"color:#6f42c1\">getByRole</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;button&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  assert.</span><span style=\"color:#6f42c1\">ok</span><span style=\"color:#24292e\">(</span><span style=\"color:#6f42c1\">isInDocument</span><span style=\"color:#24292e\">(button), </span><span style=\"color:#032f62\">&quot;button not in dom&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  assert.</span><span style=\"color:#6f42c1\">ok</span><span style=\"color:#24292e\">(</span><span style=\"color:#6f42c1\">hasTextContent</span><span style=\"color:#24292e\">(button, </span><span style=\"color:#032f62\">&quot;Count: 0&quot;</span><span style=\"color:#24292e\">), </span><span style=\"color:#032f62\">&quot;wrong text content&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">});</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#6f42c1\">testCounter</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;it increases its value on click&quot;</span><span style=\"color:#24292e\">, </span><span style=\"color:#d73a49\">async</span><span style=\"color:#24292e\"> () </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> {</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6f42c1\">render</span><span style=\"color:#24292e\">(() </span><span style=\"color:#d73a49\">=&gt;</span><span style=\"color:#24292e\"> &lt;</span><span style=\"color:#e36209\">Counter</span><span style=\"color:#24292e\"> /&gt;);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#d73a49\">const</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">button</span><span style=\"color:#24292e\"> </span><span style=\"color:#d73a49\">=</span><span style=\"color:#24292e\"> screen.</span><span style=\"color:#6f42c1\">getByRole</span><span style=\"color:#24292e\">(</span><span style=\"color:#032f62\">&quot;button&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  fireEvent.</span><span style=\"color:#6f42c1\">click</span><span style=\"color:#24292e\">(button);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#6a737d\">// the event loop takes one Promise to resolve to be finished</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#d73a49\">await</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">Promise</span><span style=\"color:#24292e\">.</span><span style=\"color:#6f42c1\">resolve</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  assert.</span><span style=\"color:#6f42c1\">ok</span><span style=\"color:#24292e\">(</span><span style=\"color:#6f42c1\">hasTextContent</span><span style=\"color:#24292e\">(button, </span><span style=\"color:#032f62\">&quot;Count: 1&quot;</span><span style=\"color:#24292e\">), </span><span style=\"color:#032f62\">&quot;not count 1 after first click&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  fireEvent.</span><span style=\"color:#6f42c1\">click</span><span style=\"color:#24292e\">(button);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  </span><span style=\"color:#d73a49\">await</span><span style=\"color:#24292e\"> </span><span style=\"color:#005cc5\">Promise</span><span style=\"color:#24292e\">.</span><span style=\"color:#6f42c1\">resolve</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">  assert.</span><span style=\"color:#6f42c1\">ok</span><span style=\"color:#24292e\">(</span><span style=\"color:#6f42c1\">hasTextContent</span><span style=\"color:#24292e\">(button, </span><span style=\"color:#032f62\">&quot;Count: 2&quot;</span><span style=\"color:#24292e\">), </span><span style=\"color:#032f62\">&quot;not count 2 after first click&quot;</span><span style=\"color:#24292e\">);</span></span>\n<span class=\"line\"><span style=\"color:#24292e\">});</span></span>\n<span class=\"line\"></span>\n<span class=\"line\"><span style=\"color:#24292e\">testCounter.</span><span style=\"color:#6f42c1\">run</span><span style=\"color:#24292e\">();</span></span>\n<span class=\"line\"></span></code></pre></section>";
var attributes = {
	title: "Testing Solid",
	description: "How to test your Solid app",
	sort: 4
};
var sections = [
	{
		slug: "testing-solid",
		title: "Testing Solid",
		level: 1,
		children: [
			{
				slug: "testing-setup",
				title: "Testing Setup",
				level: 2,
				children: [
					{
						slug: "setting-up-jest",
						title: "Setting up Jest",
						level: 3,
						children: [
							{
								slug: "using-solid-jest",
								title: "Using solid-jest",
								level: 4,
								children: [
								]
							},
							{
								slug: "using-ts-jest",
								title: "Using ts-jest",
								level: 4,
								children: [
								]
							}
						]
					},
					{
						slug: "typescript-and-jest",
						title: "TypeScript and Jest",
						level: 3,
						children: [
						]
					},
					{
						slug: "setting-up-uvu",
						title: "Setting up uvu",
						level: 3,
						children: [
						]
					},
					{
						slug: "coverage-reports",
						title: "Coverage Reports",
						level: 3,
						children: [
						]
					},
					{
						slug: "watch-mode",
						title: "Watch Mode",
						level: 3,
						children: [
						]
					},
					{
						slug: "solid-testing-library",
						title: "solid-testing-library",
						level: 3,
						children: [
						]
					},
					{
						slug: "%40testing-library%2Fjest-dom",
						title: "@testing-library/jest-dom",
						level: 3,
						children: [
						]
					},
					{
						slug: "solid-dom-testing",
						title: "solid-dom-testing",
						level: 3,
						children: [
						]
					}
				]
			},
			{
				slug: "testing-patterns-and-best-practices",
				title: "Testing Patterns and Best Practices",
				level: 2,
				children: [
					{
						slug: "testing-reactive-state",
						title: "Testing Reactive State",
						level: 3,
						children: [
							{
								slug: "testing-in-jest",
								title: "Testing in Jest",
								level: 4,
								children: [
								]
							},
							{
								slug: "testing-in-uvu",
								title: "Testing in uvu",
								level: 4,
								children: [
								]
							}
						]
					},
					{
						slug: "testing-directives",
						title: "Testing directives",
						level: 3,
						children: [
							{
								slug: "testing-in-jest-1",
								title: "Testing in Jest",
								level: 4,
								children: [
								]
							},
							{
								slug: "testing-in-uvu-1",
								title: "Testing in uvu",
								level: 4,
								children: [
								]
							}
						]
					},
					{
						slug: "testing-components",
						title: "Testing components",
						level: 3,
						children: [
							{
								slug: "testing-in-jest-2",
								title: "Testing in Jest",
								level: 4,
								children: [
								]
							},
							{
								slug: "testing-in-uvu-2",
								title: "Testing in uvu",
								level: 4,
								children: [
								]
							}
						]
					}
				]
			}
		]
	}
];
var testing = {
	html: html,
	attributes: attributes,
	sections: sections
};

export { attributes, testing as default, html, sections };
